jQuery UI Draggable - Visual feedback

### With helpers:

Original

Semi-transparent clone

Custom helper (in combination with cursorAt)

### Stacked:

We are draggables..

..whose z-indexes are controlled automatically..

..with the stack option.

Provide feedback to users as they drag an object in the form of a helper. The `helper` option accepts the values 'original' (the draggable object moves with the cursor), 'clone' (a duplicate of the draggable moves with the cursor), or a function that returns a DOM element (that element is shown near the cursor during drag). Control the helper's transparency with the `opacity` option.

To clarify which draggable is in play, bring the draggable in motion to front. Use the `zIndex` option to set a higher z-index for the helper, if in play, or use the `stack` option to ensure that the last item dragged will appear on top of others in the same group on drag stop.